.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

TotalDepth.util.gnuplot (Gnuplot Graphs Support)
========================================================

A HOWTO is here: :ref:`TotalDepth-tech-gnuplot`


.. automodule:: TotalDepth.util.gnuplot
	:member-order: bysource
	:members:
	:special-members:

